"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.init = init;

var _fs = require("fs");

var _promises = require("fs/promises");

var _pathe = require("pathe");

var _types = require("../types");

var _logger = require("@grozav/logger");

var _config = require("@inkline/config");

const interpolateString = string => string.replace(/'/g, "\\'");

const exampleConfiguration = `import { defineConfig } from '@inkline/config';

export default defineConfig({
    theme: {
        color: {
            red: '${_config.defaultConfig.theme.color.red}',
            orange: '${_config.defaultConfig.theme.color.orange}',
            yellow: '${_config.defaultConfig.theme.color.yellow}',
            green: '${_config.defaultConfig.theme.color.green}',
            teal: '${_config.defaultConfig.theme.color.teal}',
            blue: '${_config.defaultConfig.theme.color.blue}',
            purple: '${_config.defaultConfig.theme.color.purple}',
            pink: '${_config.defaultConfig.theme.color.pink}',
            white: '${_config.defaultConfig.theme.color.white}',
            black: '${_config.defaultConfig.theme.color.black}',
            primary: '<% theme.color.blue %>',
            secondary: '<% theme.color.purple %>',
            info: '<% theme.color.teal %>',
            success: '<% theme.color.green %>',
            warning: '<% theme.color.yellow %>',
            danger: '<% theme.color.red %>'
        },
        margin: '${_config.defaultConfig.theme.margin}',
        padding: '${_config.defaultConfig.theme.padding}',
        border: '${_config.defaultConfig.theme.border}',
        typography: {
            fontFamily: {
                primary: {
                    base: '${interpolateString(_config.defaultConfig.theme.typography.fontFamily.primary.base)}',
                    monospace: '${interpolateString(_config.defaultConfig.theme.typography.fontFamily.primary.monospace)}',
                    print: '${interpolateString(_config.defaultConfig.theme.typography.fontFamily.primary.print)}'
                },
                secondary: {
                    base: 'var(--font-family-primary-base)',
                    monospace: 'var(--font-family-primary-monospace)',
                    print: 'var(--font-family-primary-print)'
                }
            },
            fontSize: '${_config.defaultConfig.theme.typography.fontSize}',
            lineHeight: ${_config.defaultConfig.theme.typography.lineHeight},
            letterSpacing: ${_config.defaultConfig.theme.typography.letterSpacing}
        }
    }
});
`;

async function init(options) {
  try {
    const cwd = process.cwd();
    const isTypescript = (0, _fs.existsSync)((0, _pathe.resolve)(cwd, "tsconfig.json"));
    const outputFilePath = (0, _pathe.resolve)(cwd, isTypescript ? "inkline.config.ts" : "inkline.config.js");
    await (0, _promises.writeFile)(outputFilePath, exampleConfiguration);

    _logger.Logger.default(`Created ${outputFilePath}`);

    _logger.Logger.success(_types.Commands.Init.messages.success);
  } catch (error) {
    _logger.Logger.error(_types.Commands.Init.messages.error);

    _logger.Logger.log(error);
  }
}